Scrapes the AFTT annuaire to extract club indices, names, and provinces. Province-level entries are excluded and the province is inferred from the alphabetical prefix of the club index.
Value
A data frame with columns:
- indice
Club index code
- label
Club name
- province
Province inferred from the index
Examples
if (FALSE) { # \dontrun{
clubs <- get.club.list()
head(clubs)
} # }