These datasets store the latest and archived snapshots of the AFTT
players registry (Messieurs and Dames) as produced by
build.players.registry.m() and build.players.registry.f().
Details
Latest snapshots
players_mandplayers_fare data frames containing the latest snapshot for Messieurs and Dames respectively.Each snapshot data frame includes the following columns:
"position": current AFTT ranking of the player"position_bis": ranking excluding inactive players"nom"(if requested): player's name"classement": classement at start of season (or after mid‑season reevaluation)"club": club indice"match": number of matches played"points": points earned so far (basis for ranking)"licence": unique player ID"prov": province of the club"classement_lettre": classement letter (A, B, C, D, E, NC)"classement_chiffre": classement number (0, 2, 4, 6; 99 for A and NC)"position_bis_p": ranking of the player within their province
Each snapshot also includes attributes:
year: snapshot yearmonth: snapshot monthretrieved: POSIXct timestamp of retrieval