Estimates 'Messieurs' classement (B2 to NC) from ranking and number of actifs using a grid of average cumulated share of each classement as of share.m.B2toNC() by default
Source:R/rank2classement.R
rank2classement.RdEstimates 'Messieurs' classement (B2 to NC) from ranking and number of actifs using a grid of average cumulated share of each classement as of share.m.B2toNC() by default
Usage
rank2classement(x, N_actifs, sh_vector = share.m.B2toNC())Examples
rank2classement(9350,15780)
#> Best guess cumulated percentage based on means across columns of the provided grille. Excludes A's and B0 players as their number is fixed
#> [1] "E2"
rank2classement(9350,16780)
#> Best guess cumulated percentage based on means across columns of the provided grille. Excludes A's and B0 players as their number is fixed
#> [1] "E0"